@@ -1,6 +1,9 @@
+from s3access.s3async.core import s3client, glob
 from s3access.s3async.s3select import select, multiple, multiple_as_completed, parquets_to_csv_bytes
 
 __all__ = [
+    's3client',
+    'glob',
     'select',
     'multiple',
     'multiple_as_completed',
